@Echo Off
REM
REM SavLib.cmd, version 1.1.
REM ------------------------
REM V1.1 - Jesper Wachs, December 2015.
REM V1.0 - Jesper Wachs, November 2014.
REM
REM CMD file will save a library and transfer the savefile to
REM the PC.
REM
REM CMD file takes 5 parameters:
REM 
REM 1. (Required) Library to save.
REM 2. (Required) Name of savefile on PC that contains the library
REM 3. (Optional) Name or IP address of iSeries.
REM 4. (Optional) Userprofile to log on to iSeries.
REM 5. (Optional) Password to log on to iSeries.
Cls
REM
REM Tool configuration.
REM -------------------
set scriptfile="%~dp0%~n0.script"
set logfile="%~dp0%~n0.log"
set logfile2="%~dp0%~n02.log"
REM
REM Initial error check.
REM --------------------
REM If required parameters are missing or parm 1 is /? -?, show help text.
If "%1" == "/?" Goto Help
If "%1" == "-?" Goto Help
If "%1" == "" Goto Help
If "%2" == "" Goto Help
Goto AllGood

:Help
REM
REM Required parameters are missing.
REM
Echo.
Echo Syntax of commandfile:
Echo SAVLIB library  PC_savefile  [iseries]  [userprofile]  [password]
Echo.
Echo Description:
Echo     Save a library into a savefile and transfer the savefile to the PC.
Echo     This is done by creating scripts for the FTP command in Windows.
Echo.
Echo Parameter List:
Echo     library       The name of the library to save. Parameter is required.
Echo.
Echo     PC savefile   The path and name of the PC to contain the savefile.
Echo                   Parameter is required.
Echo.
Echo     iseries       Name or IP address of the iSeries. Parameter is optional.
Echo                   If not supplied, you will be prompted for the name.
Echo.
Echo     userprofile   The userprofile to use for logon to the FTP server on the
Echo                   iSeries. Parameter is optional. If not supplied, you will
Echo                   be prompted for the userprofile.
Echo.
Echo     password      The password associated with the userprofile. The parameter
Echo                   is optional. If not supplied, you will be prompted for the
Echo                   password.
Echo.
Pause
Goto End

:AllGood
REM
REM If parameter is missing, ask for it.
REM
If "%3" == "" (
  Echo.
  set /p iseriesname= Enter DNS-name or IP of iSeries:
  ) Else (
  set iseriesname=%3
  )
REM
REM If parameter is missing, ask for it.
REM
If "%4" == "" (
  Echo.
  set /p user= Enter id for iSeries userprofile:
  ) Else (
  set user=%4
  )
REM
REM If parameter is missing, ask for it.
REM
If "%5" == "" (
  Echo.
  set /p pwd= Enter password for iSeries userprofile:
  ) Else (
  set pwd=%5
  )
REM
REM Connect and test if userprofile and password id ok and that
REM target is an iSeries.
REM
Echo.
Echo Verifying system, user id and password.
Echo.
Echo Please wait...
Echo.
REM
REM Create FTP script to be executed on the iSeries.
REM
Echo open %iseriesname% > %scriptfile%
Echo %user% >> %scriptfile%
Echo %pwd% >> %scriptfile%
Echo quote system >> %scriptfile%
Echo Quit >> %scriptfile%
REM
REM Execute FTP
REM
FTP -s:%scriptfile% > %logfile2% 2>&1
REM
REM Check if user was rejected.
REM
FIND "530 " < "%logfile2%" > nul
If not errorlevel == 1 (
Echo.
Call :ErrHdr
Call :ErrDetLin "User id/password is not correct on target system."
Call :ErrFtr
Call :ErrFTPLog
Pause
Goto Exit
)
REM
REM If user was not rejected, user must be logged on.
REM
FIND "230 " < "%logfile2%" > nul
If errorlevel == 1 (
Echo.
Call :ErrHdr
Call :ErrDetLin "User could not be logged on target system."
Call :ErrFtr
Call :ErrFTPLog
Pause
Goto Exit
)
REM
REM Check that we are connected to an iSeries.
REM
FIND "OS/400" < "%logfile2%" > nul
If errorlevel == 1 (
Call :ErrHdr
Call :ErrDetLin "Target system is not an iSeries."
Call :ErrFtr
Call :ErrFTPLog
Pause
Goto Exit
)
Echo.
Echo Verification successful.
Echo.
REM
REM Check that the library exist on the iSeries.
REM
Echo.
Echo Verifying if library %1 exists.
Echo.
Echo Please wait...
Echo.
REM
REM Create FTP script to be executed on the iSeries.
REM
Echo open %iseriesname% > %scriptfile%
Echo %user% >> %scriptfile%
Echo %pwd% >> %scriptfile%
Echo quote rcmd chkobj %1 *lib >> %scriptfile%
Echo Quit >> %scriptfile%
REM
REM Execute FTP
REM
FTP -s:%scriptfile% > %logfile% 2>&1
REM
REM Check if an error occured on the CHKOBJ command.
REM
FIND "550-" < %logfile% > %logfile2%
If errorlevel == 1 Goto C250
Call :ErrHdr
Call :ErrDetLin "Test for library %1 did not execute correctly."
Call :ErrFtr
Call :ErrFTPLog
Pause
Goto Exit

:C250
REM
REM In this case, the system must have returned 250 which means ok.
FIND "250" < %logfile% > %logfile2%
if errorlevel == 1 (
Call :ErrHdr
Call :ErrDetLin "Test for library %1 did not execute correctly."
Call :ErrFtr
Call :ErrFTPLog
Pause
Goto Exit
)

:XFer
REM
REM Save library and transfer the savfile to pc.
REM
Echo.
Echo Saving library and transfering to pc.
Echo.
Echo Please wait...
Echo.
REM
REM Create FTP script to be executed on the iSeries.
REM
Echo open %iseriesname% > %scriptfile%
Echo %user% >> %scriptfile%
Echo %pwd% >> %scriptfile%
Echo quote rcmd crtsavf qtemp/tmpsavf >> %scriptfile%
Echo quote rcmd savlib %1 dev(*savf) savf(qtemp/tmpsavf) dtacpr(*yes) >> %scriptfile%
Echo bin >> %scriptfile%
Echo quote site namefmt 1 >> %scriptfile%
Echo get /QSYS.LIB/QTEMP.LIB/TMPSAVF.SAVF %2 >> %scriptfile%
Echo quote rcmd DLTF QTEMP/TMPSAVF >> %scriptfile%
Echo Quit >> %scriptfile%
REM
REM Execute FTP
REM
FTP -s:%scriptfile% > %logfile% 2>&1
REM
REM Check that we are connected to an iSeries.
REM
FIND "550" < %logfile% > %logfile2%
If errorlevel == 1 Goto Cont2
Echo.
Call :ErrHdr
Call :ErrDetLin "Could not save library or transfer savefile %savf%."
Call :ErrFtr
Call :ErrFTPLog
Pause
Goto Exit

:Cont2
Echo.
Echo Transfer successful.
Echo.
if exist %logfile%    del %logfile%
if exist %logfile2%   del %logfile2%
Goto End

:Exit
REM
REM Error Exit
REM
Echo.
Echo The commandfile has been terminated.
Echo.
Echo You can find the logfile in this directory. It is called:
Echo.
Echo - %logfile%
Echo.
Pause

:End
if exist %scriptfile%  del %scriptfile%
if exist %logfile2%    del %logfile2%
set iseriesname=
set user=
set pwd=
set scriptfile=
set logfile=
set logfile2=
Goto :eof

REM
REM Subroutines
REM -----------
REM
REM Write Error Header
REM on screen and in file.
REM ----------------------
:ErrHdr
REM
REM For the error log file, the configuration and other info is written.
REM
Echo %~n0 error log. > "%logfile%"
Echo ------------------- >> "%logfile%"
Echo Date/time: %date% %time% >> "%logfile%"
Echo ======================================================================== >> "%logfile%"
Echo iSeries name......: %iseriesname% >> "%logfile%"
Echo User id...........: %user% >> "%logfile%"

Call :ErrDetLin "========================================================================"
Call :ErrDetLin "Error occured."
Call :ErrDetLin "--------------"
Exit /b

REM
REM Write Error detail line
REM on screen and in file.
REM -----------------------
:ErrDetLin Str
if "%~1" == "" Echo.
if not "%~1" == "" Echo %~1

if "%~1" == "" Echo. >> "%logfile%"
if not "%~1" == "" Echo %~1 >> "%logfile%"
Exit /b

REM
REM Write Error Footer
REM on screen and in file.
REM ----------------------
:ErrFtr
Call :ErrDetLin "========================================================================"
Exit /b

REM
REM Write FTP error log
REM on screen and in file.
REM ----------------------
:ErrFTPLog
Call :ErrDetLin ""
Call :ErrDetLin "Check the log below:"
Call :ErrDetLin "--------------------------[ Start of log ]------------------------------"
Type "%logfile2%"
Type "%logfile2%" >> "%logfile%"
Call :ErrDetLin "---------------------------[ End of log ]-------------------------------"
Exit /b
